@@ -65,7 +65,7 @@ LogDialog::LogDialog(KConfig& cfg, QWidget *parent)
     , partConfig(cfg)
 {
     setButtons(Ok | Apply | Close | Help | User1 | User2 | User3);
-    setButtonGuiItem(User1, KGuiItem(i18n("&Annotate")));
+    setButtonGuiItem(User1, KGuiItem(i18n("&Annotate A")));
     setButtonGuiItem(User2, KGuiItem(i18n("&Diff"), "vcs_diff"));
     setButtonGuiItem(User3, KGuiItem(i18n("&Find"), "edit-find"));
     setDefaultButton(Close);
@@ -204,7 +204,7 @@ LogDialog::LogDialog(KConfig& cfg, QWidget *parent)
     connect(this,SIGNAL(okClicked()),
             this, SLOT(slotOk()));
     connect(this,SIGNAL(applyClicked()),this,SLOT(slotApply()));
-    setButtonGuiItem(Ok, KGuiItem(i18nc("to view something", "&View"),"document-open"));
+    setButtonGuiItem(Ok, KGuiItem(i18nc("to view revision A", "&View A"),"document-open"));
     setButtonGuiItem(Apply, KGuiItem(i18n("Create Patch...")));
     setHelp("browsinglogs");
 
@@ -302,29 +302,35 @@ bool LogDialog::parseCvsLog(OrgKdeCervisiaCvsserviceCvsserviceInterface* service
                 }
                 break;
             case Revision:
-                logInfo.m_revision = rev = line.section(' ', 1, 1);
-                state = Author;
+                if( line.startsWith(QLatin1String("revision ")) )
+                {
+                    logInfo.m_revision = rev = line.section(' ', 1, 1);
+                    state = Author;
+                }
                 break;
             case Author:
                 {
-                    QStringList strList = line.split(';');
+                    if( line.startsWith(QLatin1String("date: ")) )
+                    {
+                        QStringList strList = line.split(';');
 
-                    // convert date into ISO format (YYYY-MM-DDTHH:MM:SS)
-                    int len = strList[0].length();
-                    QString dateTimeStr = strList[0].right(len-6); // remove 'date: '
-                    dateTimeStr.replace('/', '-');
+                        // convert date into ISO format (YYYY-MM-DDTHH:MM:SS)
+                        int len = strList[0].length();
+                        QString dateTimeStr = strList[0].right(len-6); // remove 'date: '
+                        dateTimeStr.replace('/', '-');
 
-                    QString date = dateTimeStr.section(' ', 0, 0);
-                    QString time = dateTimeStr.section(' ', 1, 1);
-                    logInfo.m_dateTime.setTime_t(KDateTime::fromString(date + 'T' + time).toTime_t());
+                        QString date = dateTimeStr.section(' ', 0, 0);
+                        QString time = dateTimeStr.section(' ', 1, 1);
+                        logInfo.m_dateTime.setTime_t(KDateTime::fromString(date + 'T' + time).toTime_t());
 
-                    logInfo.m_author = strList[1].section(':', 1, 1).trimmed();
+                        logInfo.m_author = strList[1].section(':', 1, 1).trimmed();
 
-                    state = Branches;
+                        state = Branches;
+                    }
                 }
                 break;
             case Branches:
-                if( !line.startsWith("branches:") )
+                if( !line.startsWith(QLatin1String("branches:")) )
                 {
                     logInfo.m_comment = line;
                     state = Comment;
@@ -333,7 +339,13 @@ bool LogDialog::parseCvsLog(OrgKdeCervisiaCvsserviceCvsserviceInterface* service
             case Comment:
                 if( line == "----------------------------" )
                 {
-                    state = Revision;
+                    QStringList lines = dlg.getOutput();
+                    if( (lines.count() >= 2) &&  // at least revision and date line must follow
+                         lines[0].startsWith(QLatin1String("revision ")) &&
+                         lines[1].startsWith(QLatin1String("date: ")) )
+                    {
+                        state = Revision;
+                    }
                 }
                 else if( line == "=============================================================================" )
                 {
@@ -583,9 +595,9 @@ void LogDialog::updateButtons()
     // both versions selected?
     else if( !selectionA.isEmpty() && !selectionB.isEmpty() )
     {
-        enableButton(User1, false); // annotate
+        enableButton(User1, true);  // annotate A
         enableButton(User2, true);  // diff
-        enableButtonOk(false);      // view
+        enableButtonOk(true);       // view A
         enableButtonApply(true);    // create patch
     }
     // only single version selected?
