@@ -153,7 +153,7 @@ KTextEditor::Document *KateDocManager::createDoc (const KateDocumentInfo& docInf
   modelitem->setData(QVariant::fromValue(doc), DocumentRole);
 //   modelitem->setData(m_docList.count()-1, OpeningOrderRole);
   modelitem->setEditable(false);
-  modelitem->setIcon(KIcon("null"));
+  modelitem->setIcon(KIcon ("null"));
   modelitem->setToolTip(doc->url().prettyUrl());
   modelitem->setData(false,RestoreOpeningFailedRole);
   appendRow(modelitem);
@@ -191,7 +191,7 @@ void KateDocManager::slotDocumentNameChanged(KTextEditor::Document* doc)
 
 void KateDocManager::deleteDoc (KTextEditor::Document *doc)
 {
-  KateApp::self()->emitDocumentClosed(QString("%1").arg((long)doc));
+  KateApp::self()->emitDocumentClosed(QString("%1").arg((qptrdiff)doc));
   kDebug()<<"deleting document with name:"<<doc->documentName();
   int remove_row=-1;
   int rows = rowCount();
@@ -210,19 +210,22 @@ void KateDocManager::deleteDoc (KTextEditor::Document *doc)
   emit documentWillBeDeleted (doc);
   emit m_documentManager->documentWillBeDeleted (doc);
 
+
+  for (int i=0;i<rowCount();i++) {
+        kDebug()<<data(index(i,0),Qt::DisplayRole)<<(i==remove_row?"REMOVING":"");
+  }
+  if (remove_row>-1)
+      removeRow(remove_row);
+  
   // really delete the document and it's infos
   delete m_docInfos.take (doc);
   delete m_docList.takeAt (m_docList.indexOf(doc));
-
+  
+  //??????????????? AT THIS POINT THE REFERENCED POINTER IS INVALID
   // document is gone, emit our signals
   emit documentDeleted (doc);
   emit m_documentManager->documentDeleted (doc);
 
-  for (int i=0;i<rowCount();i++) {
-	kDebug()<<data(index(i,0),Qt::DisplayRole)<<(i==remove_row?"REMOVING":"");
-  }
-  if (remove_row>-1)
-      removeRow(remove_row);
 
 }
 
@@ -510,6 +513,15 @@ void KateDocManager::saveAll()
     doc->documentSave();
 }
 
+void KateDocManager::saveSelected(const QList<KTextEditor::Document*> &docList)
+{
+  foreach(KTextEditor::Document* doc, docList)
+  {
+    if ( doc->isModified() )
+      doc->documentSave();
+  }
+}
+
 void KateDocManager::reloadAll()
 {
   foreach ( KTextEditor::Document *doc, m_docList )
@@ -566,7 +578,6 @@ void KateDocManager::restoreDocumentList (KConfig* config)
   pd->progressBar()->setRange(0, count);
 
   bool first = true;
-  const int countM1 = count - 1;
   m_documentStillToRestore = count;
   m_restoringDocumentList = true;
   m_openingErrors.clear();
@@ -719,34 +730,18 @@ void KateDocManager::slotModChanged1(KTextEditor::Document * doc)
   kDebug() << "KateDocManager::slotModChanged (2)";
   QStandardItem *item = m_documentItemMapping[doc];
   const KateDocumentInfo *info = KateDocManager::self()->documentInfo(doc);
-  item->setIcon(QIcon());
+  item->setIcon(KIcon("null"));
   if (info && info->modifiedOnDisc)
   {
-    if (doc->isModified()) item->setIcon(KIcon("modmod"));
-    else item->setIcon(KIcon("modonhd"));
+    if (doc->isModified()) item->setIcon(KIcon("document-save", 0, QStringList () << "emblem-important"));
+    else item->setIcon(KIcon("dialog-warning"));
 
-    KateApp::self()->activeMainWindow()->queueModifiedOnDisc(doc);      
+    KateApp::self()->activeMainWindow()->queueModifiedOnDisc(doc);
   } else
-    if (doc->isModified()) item->setIcon(KIcon("modified"));
+    if (doc->isModified()) item->setIcon(KIcon("document-save"));
     else item->setIcon(KIcon("null"));
-  /*  if ( column == 0) {
-      static QPixmap noPm = SmallIcon ("null");
-      static QPixmap modPm = SmallIcon("modified");
-      static QPixmap discPm = SmallIcon("modonhd");
-      static QPixmap modmodPm = SmallIcon("modmod");
-
-      const KateDocumentInfo *info = KateDocManager::self()->documentInfo(doc);
-
-      if (info && info->modifiedOnDisc)
-        return doc->isModified() ? &modmodPm : &discPm;
-      else
-        return doc->isModified() ? &modPm : &noPm;
-    }
-
-    return 0; */
 }
 
-
 QModelIndex KateDocManager::indexForDocument(KTextEditor::Document *document)
 {
   int row = m_docList.indexOf(document);
@@ -757,7 +752,7 @@ QModelIndex KateDocManager::indexForDocument(KTextEditor::Document *document)
 void KateDocManager::documentOpened()
 {
   KColorScheme colors(QPalette::Active);
-  
+
   KTextEditor::Document *doc = qobject_cast<KTextEditor::Document*>(sender());
   if (!doc) return; // should never happen, but who knows
   doc->setSuppressOpeningErrorDialogs(false);
