@@ -22,6 +22,7 @@
 // Icons
 // Direct shortcut setting
 //BEGIN Includes
+#include "kateexternaltoolsplugin.h"
 #include "kateexternaltools.h"
 #include "kateexternaltools.moc"
 #include <KTextEditor/View>
@@ -44,6 +45,7 @@
 #include <KMenu>
 #include <KSharedConfig>
 #include <kdebug.h>
+#include <kde_file.h>
 
 #include <QBitmap>
 #include <QFile>
@@ -58,7 +60,6 @@
 #include <unistd.h>
 //END Includes
 
-KateExternalToolsCommand *KateExternalToolsCommand::s_self = 0;
 
 //BEGIN KateExternalTool
 KateExternalTool::KateExternalTool( const QString &name,
@@ -86,14 +87,14 @@ bool KateExternalTool::checkExec()
 {
   // if tryexec is empty, it is the first word of command
   if ( tryexec.isEmpty() )
-    tryexec = command.section( " ", 0, 0, QString::SectionSkipEmpty );
+    tryexec = command.section( ' ', 0, 0, QString::SectionSkipEmpty );
 
   // NOTE this code is modified taken from kdesktopfile.cpp, from KDesktopFile::tryExec()
   if (!tryexec.isEmpty())
   {
     if (tryexec[0] == '/')
     {
-      if (::access(QFile::encodeName(tryexec), R_OK | X_OK))
+      if (KDE::access(tryexec, R_OK | X_OK))
         return false;
 
       m_exec = tryexec;
@@ -104,17 +105,13 @@ bool KateExternalTool::checkExec()
       // Environment PATH may contain filenames in 8bit locale cpecified
       // encoding (Like a filenames).
       const QString path = QFile::decodeName(qgetenv("PATH"));
-#ifdef Q_WS_WIN
-      const QStringList dirs = path.split(';', QString::SkipEmptyParts);
-#else
-      const QStringList dirs = path.split(':', QString::SkipEmptyParts);
-#endif
+      const QStringList dirs = path.split(KPATH_SEPARATOR, QString::SkipEmptyParts);
       QStringList::ConstIterator it(dirs.begin());
       bool match = false;
       for (; it != dirs.end(); ++it)
       {
         QString fName = *it + '/' + tryexec;
-        if (::access(QFile::encodeName(fName), R_OK | X_OK) == 0)
+        if (KDE::access(fName, R_OK | X_OK) == 0)
         {
           match = true;
           m_exec = fName;
@@ -137,7 +134,7 @@ bool KateExternalTool::valid( const QString &mt ) const
 //END KateExternalTool
 
 //BEGIN KateExternalToolsCommand
-KateExternalToolsCommand::KateExternalToolsCommand() : KTextEditor::Command()
+KateExternalToolsCommand::KateExternalToolsCommand(KateExternalToolsPlugin *plugin) : KTextEditor::Command(),m_plugin(plugin)
 {
   m_inited = false;
   reload();
@@ -148,12 +145,6 @@ const QStringList &KateExternalToolsCommand::cmds ()
   return m_list;
 }
 
-KateExternalToolsCommand *KateExternalToolsCommand::self ()
-{
-  if (s_self) return s_self;
-  s_self = new KateExternalToolsCommand;
-  return s_self;
-}
 
 void KateExternalToolsCommand::reload ()
 {
@@ -212,21 +203,20 @@ bool KateExternalToolsCommand::exec (KTextEditor::View *view, const QString &cmd
 //   kDebug(13001)<<"KateExternalToolsCommand::exec: Could not get view widget";
     return false;
   }
-  KXmlGuiWindow *dmw = dynamic_cast<KXmlGuiWindow*>(wv->window());
-  if (!dmw)
-  {
-//   kDebug(13001)<<"KateExternalToolsCommand::exec: Could not get main window";
-    return false;
-  }
+
+
 //  kDebug(13001)<<"cmd="<<cmd.trimmed();
   QString actionName = m_map[cmd.trimmed()];
   if (actionName.isEmpty()) return false;
 //  kDebug(13001)<<"actionName is not empty:"<<actionName;
-  KateExternalToolsMenuAction *a =
+/*  KateExternalToolsMenuAction *a =
     dynamic_cast<KateExternalToolsMenuAction*>(dmw->action("tools_external"));
-  if (!a) return false;
+  if (!a) return false;*/
+  KateExternalToolsPluginView *extview=m_plugin->extView(wv->window());
+  if (!extview) return false;
+  if (!extview->externalTools) return false;
 //  kDebug(13001)<<"trying to find action";
-  QAction *a1 = a->actionCollection()->action(actionName.toUtf8().constData ());
+  QAction *a1 = extview->externalTools->actionCollection()->action(actionName.toUtf8().constData ());
   if (!a1) return false;
 //  kDebug(13001)<<"activating action";
   a1->trigger();
@@ -352,7 +342,9 @@ KateExternalToolsMenuAction::~KateExternalToolsMenuAction()
 
 void KateExternalToolsMenuAction::reload()
 {
+  bool needs_readd=(m_actionCollection->takeAction(this)!=0);
   m_actionCollection->clear ();
+  if (needs_readd) m_actionCollection->addAction("tools_external",this);
   menu()->clear();
 
   // load all the tools, and create a action for each of them
@@ -571,7 +563,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
   btnMTW->setIcon(QIcon(SmallIcon("wizard")));
   connect(btnMTW, SIGNAL(clicked()), this, SLOT(showMTDlg()));
   btnMTW->setWhatsThis(i18n(
-                         "Click for a dialog that can help you creating a list of mimetypes.") );
+                         "Click for a dialog that can help you create a list of mimetypes.") );
 
   cmbSave = new KComboBox(w);
   lo->addWidget( cmbSave, 5, 2, 1, 2 );
@@ -585,7 +577,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
   cmbSave->addItems( sl );
   if ( tool ) cmbSave->setCurrentIndex( tool->save );
   cmbSave->setWhatsThis(i18n(
-                          "You can elect to save the current or all [modified] documents prior to "
+                          "You can choose to save the current or all [modified] documents prior to "
                           "running the command. This is helpful if you want to pass URLs to "
                           "an application like, for example, an FTP client.") );
 
@@ -599,21 +591,26 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
   if ( tool ) leCmdLine->setText( tool->cmdname );
   leCmdLine->setWhatsThis(i18n(
                             "If you specify a name here, you can invoke the command from the view "
-                            "command lines with exttool-the_name_you_specified_here. "
+                            "command line with exttool-the_name_you_specified_here. "
                             "Please do not use spaces or tabs in the name."));
-  connect(this, SIGNAL(okClicked()), this, SLOT(slotOk()));
 }
 
-void KateExternalToolServiceEditor::slotOk()
+void KateExternalToolServiceEditor::slotButtonClicked(int button)
 {
-  if ( leName->text().isEmpty() ||
-       teCommand->text().isEmpty() )
-  {
-    KMessageBox::information( this, i18n("You must specify at least a name and a command") );
-    return;
+  switch( button ) {
+    case Ok:
+      if ( leName->text().isEmpty() || teCommand->document()->isEmpty() )
+      {
+        KMessageBox::information( this, i18n("You must specify at least a name and a command") );
+        return;
+      }
+      accept();
+      break;
+    case Cancel:
+      reject();
+      break;
   }
 
-  KDialog::accept();
 }
 
 void KateExternalToolServiceEditor::showMTDlg()
@@ -629,9 +626,10 @@ void KateExternalToolServiceEditor::showMTDlg()
 //END KateExternalToolServiceEditor
 
 //BEGIN KateExternalToolsConfigWidget
-KateExternalToolsConfigWidget::KateExternalToolsConfigWidget( QWidget *parent, const char* name)
+KateExternalToolsConfigWidget::KateExternalToolsConfigWidget( QWidget *parent, KateExternalToolsPlugin *plugin, const char* name)
     : Kate::PluginConfigPage( parent, name )
     , m_changed( false )
+    , m_plugin(plugin)
 {
   setupUi(this);
 
@@ -763,6 +761,7 @@ void KateExternalToolsConfigWidget::apply()
   }
 
   config->sync();
+  m_plugin->reload();
 }
 
 void KateExternalToolsConfigWidget::slotSelectionChanged()
@@ -785,7 +784,7 @@ void KateExternalToolsConfigWidget::slotNew()
   {
     KateExternalTool *t = new KateExternalTool(
                             editor.leName->text(),
-                            editor.teCommand->text(),
+                            editor.teCommand->toPlainText(),
                             editor.btnIcon->icon(),
                             editor.leExecutable->text(),
                             editor.leMimetypes->text().split( QRegExp("\\s*;\\s*"), QString::SkipEmptyParts ) );
@@ -831,7 +830,7 @@ void KateExternalToolsConfigWidget::slotEdit()
 
     t->name = editor.leName->text();
     t->cmdname = editor.leCmdLine->text();
-    t->command = editor.teCommand->text();
+    t->command = editor.teCommand->toPlainText();
     t->icon = editor.btnIcon->icon();
     t->tryexec = editor.leExecutable->text();
     t->mimetypes = editor.leMimetypes->text().split( QRegExp("\\s*;\\s*"), QString::SkipEmptyParts );
