@@ -16,22 +16,23 @@
 #ifndef KBBMAINWINDOW_H
 #define KBBMAINWINDOW_H
 
-#include <kapplication.h>
 #include <kbookmarkmanager.h>
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 #include <qmap.h>
+//Added by qt3to4:
+#include <QLabel>
 
 #include "package.h"
 #include "bug.h"
 #include "bugdetails.h"
 
-class KAction;
+class QAction;
 class KActionMenu;
+class KAction;
 class KBookmarkMenu;
 class KToggleAction;
 class KSelectAction;
 class QLabel;
-class QListViewItem;
 class QProgressBar;
 class PreferencesDialog;
 class TextViewer;
@@ -45,23 +46,23 @@ namespace KBugBusterMainWindow
 /**
  * @author Martijn Klingens
  */
-class KBBMainWindow : public KMainWindow, virtual public KBookmarkOwner
+class KBBMainWindow : public KXmlGuiWindow, virtual public KBookmarkOwner
 {
     Q_OBJECT
   public:
     /**
      * construtor of KBugBusterApp, calls all init functions to create the application.
      */
-    KBBMainWindow( const QCString &initialPackage = "",
-                   const QCString &initialCpomponent = "",
-                   const QCString &initialBug = "",
-                   QWidget* parent = 0, const char* name = 0 );
+    explicit KBBMainWindow( const QByteArray &initialPackage = "",
+			    const QByteArray &initialCpomponent = "",
+    			    const QByteArray &initialBug = "",
+    			    QWidget* parent = 0, const char* name = 0 );
     ~KBBMainWindow();
 
     /// Overloaded functions of KBookmarkOwner
-    virtual void openBookmarkURL( const QString & _url );
+    virtual void openBookmark(const KBookmark & bm, Qt::MouseButtons mb, Qt::KeyboardModifiers km);
     virtual QString currentTitle() const;
-    virtual QString currentURL() const;
+    virtual QString currentUrl() const;
 
   public slots:
     /**
@@ -110,12 +111,12 @@ class KBBMainWindow : public KMainWindow, virtual public KBookmarkOwner
     /**
      * Used KActions
      */
-    KAction *fileQuit;
+    QAction *fileQuit;
     KAction *reloadpacklist;
     KAction *reloadpack;
     KAction *reloadbug;
     KAction *reloadall;
-    KAction *loadMyBugs;
+    QAction *loadMyBugs;
     KToggleAction *m_disconnectedAction;
 
     /**
