@@ -2,7 +2,7 @@
                                 kompareprefdlg.h
                                 ----------------
         begin                   : Sun Mar 4 2001
-        Copyright 2001-2003 Otto Bruggeman <otto.bruggeman@home.nl>
+        Copyright 2001-2009 Otto Bruggeman <bruggie@gmail.com>
         Copyright 2001-2003 John Firebaugh <jfirebaugh@kde.org>
         Copyright 2007      Kevin Kofler   <kevin.kofler@chello.at>
 ****************************************************************************/
@@ -45,6 +45,9 @@ protected slots:
 	/** No descriptions */
 	virtual void slotCancel();
 
+signals:
+	void configChanged();
+
 private:
 	ViewPage* m_viewPage;
 	DiffPage* m_diffPage;
